summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--oslo_messaging/_drivers/common.py2
-rw-r--r--oslo_messaging/_drivers/impl_rabbit.py8
2 files changed, 5 insertions, 5 deletions
diff --git a/oslo_messaging/_drivers/common.py b/oslo_messaging/_drivers/common.py
index 44cfe55..c3c70de 100644
--- a/oslo_messaging/_drivers/common.py
+++ b/oslo_messaging/_drivers/common.py
@@ -373,7 +373,7 @@ class DecayingTimer(object):
# greenthread.
# So, a connection cannot be shared between thread/greenthread and
# this two variables permit to define the purpose of the connection
-# to allow drivers to add special handling if needed (like heatbeat).
+# to allow drivers to add special handling if needed (like heartbeat).
# amqp drivers create 3 kind of connections:
# * driver.listen*(): each call create a new 'PURPOSE_LISTEN' connection
# * driver.send*(): a pool of 'PURPOSE_SEND' connections is used
diff --git a/oslo_messaging/_drivers/impl_rabbit.py b/oslo_messaging/_drivers/impl_rabbit.py
index ec5643c..f45b845 100644
--- a/oslo_messaging/_drivers/impl_rabbit.py
+++ b/oslo_messaging/_drivers/impl_rabbit.py
@@ -610,7 +610,7 @@ class Connection(object):
# expected waiting the events drain, we start heartbeat_check and
# retrieve the server heartbeat packet only two times more than
# the minimum required for the heartbeat works
- # (heatbeat_timeout/heartbeat_rate/2.0, default kombu
+ # (heartbeat_timeout/heartbeat_rate/2.0, default kombu
# heartbeat_rate is 2)
self._heartbeat_wait_timeout = (
float(self.heartbeat_timeout_threshold) /
@@ -635,7 +635,7 @@ class Connection(object):
# NOTE(sileht): value chosen according the best practice from kombu
# http://kombu.readthedocs.org/en/latest/reference/kombu.common.html#kombu.common.eventloop
# For heatbeat, we can set a bigger timeout, and check we receive the
# heartbeat packets regulary
if self._heartbeat_supported_and_enabled():
self._poll_timeout = self._heartbeat_wait_timeout
@@ -1014,8 +1014,8 @@ class Connection(object):
"occurred, trying to reconnect: %s"), exc)
self.ensure_connection()
except Exception:
- LOG.warning(_LW("Unexpected error during heartbeart "
- "thread processing, retrying..."))
+ LOG.warning(_LW("Unexpected error during heartbeat "
+ "thread processing, retrying..."))
LOG.debug('Exception', exc_info=True)
self._heartbeat_exit_event.wait(
@@ -635,7 +635,7 @@ class Connection(object):
# NOTE(sileht): value chosen according the best practice from kombu
# http://kombu.readthedocs.org/en/latest/reference/kombu.common.html#kombu.common.eventloop
- # For heatbeat, we can set a bigger timeout, and check we receive the
+ # For heartbeat, we can set a bigger timeout, and check we receive the
# heartbeat packets regulary
if self._heartbeat_supported_and_enabled():